@@ -1,6 +1,10 @@
+from past.builtins import basestring
+import os
 import json
 import requests
-from transcriptic.objects import Run, Project, Aliquot, Resource, Container
+from transcriptic.objects import Run, Project, Aliquot, Resource, Container, Dataset, ProtocolPreview
+
+import sys
 
 ctx = None
 
@@ -40,8 +44,18 @@ def aliquot(id):
 def container(id):
   return _get_object(id, Container)
 
+def preview(protocol):
+  _check_ctx()
+  return ProtocolPreview(protocol, connection = ctx)
+
 def analyze(protocol, test_mode = False):
   _check_ctx()
+  if "errors" in protocol:
+      raise AnalysisException(("Error%s in protocol:\n%s" %
+      (("s" if len(protocol["errors"]) > 1 else ""),
+        "".join(["- " + e['message'] + "\n" for
+        e in protocol["errors"]]))))
+
   req = ctx.post('analyze_run', data = json.dumps({
     "protocol": protocol,
     "test_mode": test_mode
@@ -77,6 +91,7 @@ def dataset(id, key = "*"):
   _check_ctx()
   req = ctx.get("/data/%s.json?key=%s" % (id, key))
   if req.status_code == 200:
-    return req.json()
+    data = req.json()
+    return Dataset(id, data, connection = ctx)
   else:
     raise Exception("[%d] %s" % (req.status_code, req.text))
