@@ -1,5 +1,9 @@
+from __future__ import division
+from __future__ import print_function
+from builtins import range
+from past.utils import old_div
+from builtins import object
 import plotly.plotly as py
-from plotly.graph_objs import plot
 import pandas
 import matplotlib.pyplot as plt
 import plotly.tools as tls
@@ -26,7 +30,7 @@ class PlateRead(object):
         self.op_type = op_type
         if "data_keys" not in self.dataset.attributes or len(self.dataset.attributes["data_keys"]) == 0:
             raise RuntimeError("No data found in given dataset.")
-        if self.op_type not in ["absorbance", "fluorescence", "luminsence"]:
+        if self.op_type not in ["absorbance", "fluorescence", "luminescence"]:
             raise RuntimeError("Data given is not from a spectrophotometry operation.")
         if self.op_type != self.dataset.attributes["instruction"]["operation"]["op"]:
             raise RuntimeError("Data given is not a %s operation." % op_type)
@@ -39,7 +43,7 @@ class PlateRead(object):
         if self.op_type == "fluorescence":
             measure_params_dict["wavelength"] = "excitation: %s emission: %s" % (self.dataset.attributes["instruction"]["operation"]["excitation"].split(":")[0] + "nm",
                  self.dataset.attributes["instruction"]["operation"]["emission"].split(":")[0] + "nm")
-        if self.op_type == "luminsence":
+        if self.op_type == "luminescence":
             measure_params_dict["wavelength"] = ""
 
         self.params = measure_params_dict
@@ -52,13 +56,13 @@ class PlateRead(object):
         self.params["plate"] = plate_info_dict
 
         # Get dataset and parse into DataFrame
-        data_dict = get_dataset(self.dataset.attributes["id"])
+        data_dict = get_dataset(self.dataset.attributes["id"]).attributes
         df_dict = {}
         well_count = self.dataset.attributes["container_type"]["well_count"]
         col_count = self.dataset.attributes["container_type"]["col_count"]
         # If no group well list specified, default to including all well data values in one group
         if not group_wells:
-            df_dict[group_labels[0]] = [x[0] for x in data_dict.values()]
+            df_dict[group_labels[0]] = [x[0] for x in list(data_dict.values())]
         # If given list of all int, assume one group with all wells in list
         elif all(isinstance(i, int) for i in group_wells):
             if len(group_wells) > len(data_dict):
@@ -120,7 +124,7 @@ class PlateRead(object):
                         "xaxis": {
                             "tickmode": "array",
                             "ticktext": labels,
-                            "tickvals": range(1, len(labels)+1),
+                            "tickvals": list(range(1, len(labels)+1)),
                             "tickangle": 0,
                             "tickfont":{
                                 "size": 10
@@ -207,7 +211,7 @@ class Absorbance(PlateRead):
             # Calculate R^2 from residuals
             ss_res = result[1]
             ss_tot = np.sum(np.square((plot_obj["values"] - plot_obj["values"].mean())))
-            print ("%s R^2: %s" % (self.name, (1-ss_res/ss_tot)))
+            print ("%s R^2: %s" % (self.name, (1-old_div(ss_res,ss_tot))))
 
 
 class Fluorescence(PlateRead):
@@ -284,9 +288,9 @@ def compare_standards(pr_obj, std_pr_obj):
     # Compare against mean of standard absorbance
     # Check to ensure CVs are at least 2 apart
     for indx in range(len(pr_obj.cv)):
-        cv_ratio = pr_obj.cv.iloc[indx]/std_pr_obj.cv.iloc[indx]
+        cv_ratio = old_div(pr_obj.cv.iloc[indx],std_pr_obj.cv.iloc[indx])
         if cv_ratio < 2:
-            print "Warning for %s: Sample CV is only %s times that of Standard CV. RMSE may be inaccurate." % (pr_obj.cv.index[indx], cv_ratio)
+            print ("Warning for %s: Sample CV is only %s times that of Standard CV. RMSE may be inaccurate." % (pr_obj.cv.index[indx], cv_ratio))
     # RMSE (normalized wrt to standard mean)
     RMSE = np.sqrt(np.square(pr_obj.df - std_pr_obj.df.mean())).mean() /  std_pr_obj.df.mean()*100
     RMSE = pandas.DataFrame(RMSE, columns=["RMSE % (normalized to standard mean)"])
@@ -296,6 +300,6 @@ def compare_standards(pr_obj, std_pr_obj):
 
     if pr_obj.name:
         display(HTML("<b>Standards Comparison (%s)</b>" % pr_obj.name))
-    print sampleVariance
-    print sampleCV
-    print RMSE
+    print(sampleVariance)
+    print(sampleCV)
+    print(RMSE)
