@@ -1,3 +1,5 @@
+from builtins import next
+from builtins import str
 #!/usr/bin/env python
 
 import sys
@@ -13,6 +15,7 @@ import re
 from transcriptic import AnalysisException, analyze as api_analyze, submit as api_submit
 from transcriptic.english import AutoprotocolParser
 from transcriptic.config import Connection
+from transcriptic.objects import ProtocolPreview
 from transcriptic.util import iter_json
 from os.path import isfile
 from collections import OrderedDict
@@ -36,7 +39,7 @@ except NameError:
 @click.pass_context
 def cli(ctx, apiroot, config, organization):
   '''A command line tool for working with Transcriptic.'''
-  if ctx.invoked_subcommand not in ['login', 'preview', 'run']:
+  if ctx.invoked_subcommand not in ['login']:
     try:
       ctx.obj = Connection.from_file(config)
       if organization is not None:
@@ -193,7 +196,7 @@ def protocols():
         click.echo("Error: Your manifest.json file is improperly formatted. "
                    "Please double check your brackets and commas!")
         return
-      if 'protocols' not in manifest.keys() or not manifest['protocols']:
+      if 'protocols' not in list(manifest.keys()) or not manifest['protocols']:
         click.echo("Your manifest.json file doesn't contain any protocols or"
                    " is improperly formatted.")
         return
@@ -216,7 +219,7 @@ def packages(ctx, i):
   '''List packages in your organization.'''
   response = ctx.obj.get('packages/')
   # there's probably a better way to do this
-  package_names = OrderedDict(sorted({"yours": {}, "theirs": {}}.items(), key=lambda t: len(t[0])))
+  package_names = OrderedDict(sorted(list({"yours": {}, "theirs": {}}.items()), key=lambda t: len(t[0])))
   if response.status_code == 200:
     for pack in response.json():
       n = str(pack['name']).lower().replace("com.%s." % ctx.obj.organization_id, "")
@@ -230,22 +233,22 @@ def packages(ctx, i):
         package_names['theirs'][n]['id'] = str(pack['id'])
         package_names['theirs'][n]['latest'] = latest
   if i:
-    return dict(package_names['yours'].items() + package_names['theirs'].items())
+    return dict(list(package_names['yours'].items()) + list(package_names['theirs'].items()))
   else:
-    for category, packages in package_names.items():
+    for category, packages in list(package_names.items()):
       if category == "yours":
         click.echo('\n{:^90}'.format("YOUR PACKAGES:\n"))
         click.echo('{:^30}'.format("PACKAGE NAME") + "|" +
                '{:^30}'.format("PACKAGE ID")
                + "|" + '{:^30}'.format("LATEST PUBLISHED VERSION"))
         click.echo('{:-^90}'.format(''))
-      elif category == "theirs" and packages.values():
+      elif category == "theirs" and list(packages.values()):
         click.echo('\n{:^90}'.format("OTHER PACKAGES IN YOUR ORG:\n"))
         click.echo('{:^30}'.format("PACKAGE NAME") + "|" +
                    '{:^30}'.format("PACKAGE ID") + "|" +
                    '{:^30}'.format("LATEST PUBLISHED VERSION"))
         click.echo('{:-^90}'.format(''))
-      for name, p in packages.items():
+      for name, p in list(packages.items()):
         click.echo('{:<30}'.format(name) + "|" +
                    '{:^30}'.format(p['id']) + "|" +
                    '{:^30}'.format(p['latest']))
@@ -310,20 +313,20 @@ def projects(ctx, i):
       else:
         proj_cats["reg"][proj.attributes['name']] =  proj.id
     if i:
-      return {k.lower(): v for k,v in proj_names.items()}
+      return {k.lower(): v for k,v in list(proj_names.items())}
     else:
-      for cat, packages in proj_cats.items():
+      for cat, packages in list(proj_cats.items()):
         if cat == "reg":
           click.echo('\n{:^80}'.format("PROJECTS:\n"))
           click.echo('{:^40}'.format("PROJECT NAME") + "|" +
                      '{:^40}'.format("PROJECT ID"))
           click.echo('{:-^80}'.format(''))
-        elif cat == "pilot" and packages.values():
+        elif cat == "pilot" and list(packages.values()):
           click.echo('\n{:^80}'.format("PILOT PROJECTS:\n"))
           click.echo('{:^40}'.format("PROJECT NAME") + "|" +
                      '{:^40}'.format("PROJECT ID"))
           click.echo('{:-^80}'.format(''))
-        for name, i in packages.items():
+        for name, i in list(packages.items()):
           click.echo('{:<40}'.format(name) + "|" +
                      '{:^40}'.format(i))
           click.echo('{:-^80}'.format(''))
@@ -380,6 +383,28 @@ def delete_project(ctx, name, force):
       else:
         click.echo("Could not archive project!")
 
+@cli.command()
+@click.argument('query', default='*')
+@click.pass_context
+def resources(ctx, query):
+    '''Search catalog of provisionable resources'''
+    req = ctx.obj.resources(query)
+    if req["results"]:
+      click.echo("Results for '%s':" % query)
+      click.echo('{:^40}'.format("Resource Name") + '|' +
+                   '{:^40}'.format("Vendor") + '|' + '{:^40}'.format("Resource ID"))
+      click.echo('{:-^120}'.format(''))
+    else:
+      click.echo("No results for '%s'." % query)
+    for i in req["results"]:
+      if i["provisionable"] and not i["reservable"]:
+        name = i['name'].encode('ascii', errors='ignore')
+        id = i['kit_items'][0]['resource_id']
+        click.echo('{:^40}'.format(name) + '|' +
+                   '{:^40}'.format(i['vendor']['name'] if 'vendor' in list(i.keys()) else '') + '|' + '{:^40}'.format(id))
+        click.echo('{:-^120}'.format(''))
+
+
 @cli.command()
 @click.argument('path', default='.')
 def init(path):
@@ -443,7 +468,9 @@ def price(response):
   count("instruction", "instructions", len(response['instructions']))
   count("container", "containers", len(response['refs']))
   locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
-  click.echo("  %s" % locale.currency(float(response['total_cost']), grouping=True))
+  click.echo("  Total Cost: %s" % locale.currency(float(response['total_cost']), grouping=True))
+  for quote_item in response['quote']['items']:
+      click.echo("  %s: %s" % (quote_item["title"], locale.currency(float(quote_item["cost"]), grouping=True)))
   for w in response['warnings']:
     message = w['message']
     if 'instruction' in w['context']:
@@ -454,7 +481,9 @@ def price(response):
 
 @cli.command()
 @click.argument('protocol_name', metavar="PROTOCOL_NAME")
-def preview(protocol_name):
+@click.option('--view', is_flag=True)
+@click.pass_context
+def preview(ctx, protocol_name, view):
   '''Preview the Autoprotocol output of protocol in the current package.'''
   with click.open_file('manifest.json', 'r') as f:
     try:
@@ -476,7 +505,7 @@ def preview(protocol_name):
   except KeyError:
     click.echo("Error: Your manifest.json file does not have a \"command_string\" key.")
     return
-  from subprocess import call
+  from subprocess import call, check_output, CalledProcessError
   import tempfile
   with tempfile.NamedTemporaryFile() as fp:
     try:
@@ -486,7 +515,16 @@ def preview(protocol_name):
                  "contain a \"preview\" section")
       return
     fp.flush()
-    call(["bash", "-c", command + " " + fp.name])
+    try:
+      protocol = check_output(["bash", "-c", command + " " + fp.name])
+      click.echo(protocol)
+      if view:
+         click.echo("View your protocol's raw JSON above or see the intructions "
+                    "rendered at the following link: \n%s" %
+                    ProtocolPreview(protocol, ctx.obj).preview_url)
+    except CalledProcessError as e:
+      click.echo(e.output)
+      return
 
 @cli.command()
 @click.argument('file', default='-')
@@ -582,7 +620,7 @@ def get_project_id(ctx, name):
   projs = ctx.invoke(projects, i=True)
   id = projs.get(name.lower())
   if not id:
-    id = name if name in projs.values() else None
+    id = name if name in list(projs.values()) else None
     if not id:
       click.echo("A project with the name '%s' was not found in your organization." % name)
       return
@@ -590,10 +628,10 @@ def get_project_id(ctx, name):
 
 @click.pass_context
 def get_project_name(ctx, id):
-  projs = {v:k for k,v in ctx.invoke(projects, i=True).items()}
+  projs = {v:k for k,v in list(ctx.invoke(projects, i=True).items())}
   name = projs.get(id)
   if not name:
-    name = id if name in projs.keys() else None
+    name = id if name in list(projs.keys()) else None
     if not name:
       click.echo("A project with the id '%s' was not found in your organization." % name)
       return
@@ -602,10 +640,10 @@ def get_project_name(ctx, id):
 @click.pass_context
 def get_package_id(ctx, name):
   package_names = ctx.invoke(packages, i=True)
-  package_names = {k.lower(): v['id'] for k,v in package_names.items()}
+  package_names = {k.lower(): v['id'] for k,v in list(package_names.items())}
   package_id = package_names.get(name)
   if not package_id:
-    package_id = name if name in package_names.values() else None
+    package_id = name if name in list(package_names.values()) else None
   if not package_id:
     click.echo("The package '%s' does not exist in your organization." % name)
     return
@@ -613,10 +651,10 @@ def get_package_id(ctx, name):
 
 @click.pass_context
 def get_package_name(ctx, id):
-  package_names = {v['id']: k for k, v in ctx.invoke(packages, i=True).items()}
+  package_names = {v['id']: k for k, v in list(ctx.invoke(packages, i=True).items())}
   package_name = package_names.get(id)
   if not package_name:
-    package_name = id if id in package_names.values() else None
+    package_name = id if id in list(package_names.values()) else None
   if not package_name:
     click.echo("The id '%s' does not match any package in your organization."
                % id)
