@@ -1,14 +1,22 @@
+from __future__ import print_function
+from builtins import object
 import requests
 import json
 import transcriptic
+import os
 from os.path import expanduser
 from transcriptic.objects import Project
 
-class Connection:
+
+class Connection(object):
   def __init__(
-      self, email, token, organization_id = False, api_root = "https://secure.transcriptic.com", organization = False,
+      self, email = None, token = None, organization_id = False, api_root = "https://secure.transcriptic.com", organization = False,
       cookie = False, verbose = False
     ):
+    if email is None:
+      email = os.environ['USER_EMAIL']
+      token = os.environ['USER_TOKEN']
+      organization_id = os.environ['USER_ORGANIZATION']
     self.api_root = api_root
     self.email = email
     self.token = token
@@ -39,7 +47,7 @@ class Connection:
 
   def url(self, path):
     if path.startswith("/"):
-      return "%s/%s" % (self.api_root, path)
+      return "%s%s" % (self.api_root, path)
     else:
       return "%s/%s/%s" % (self.api_root, self.organization_id, path)
 
@@ -99,6 +107,10 @@ class Connection:
     else:
       raise RuntimeError(req.text)
 
+  def resources(self, query):
+    req = self.get("/_commercial/kits?q=%s&per_page=1000" % query)
+    return req.json()
+
   def create_package(self, name, description):
     req = self.post('packages', data = json.dumps({
       "name": "%s%s" % ("com.%s." % self.organization_id, name),
@@ -115,19 +127,19 @@ class Connection:
         return True
 
   def post(self, path, **kwargs):
-    if self.verbose: print "POST %s" %  self.url(path)
+    if self.verbose: print ("POST %s" %  self.url(path))
     return requests.post(self.url(path), headers = self._merge_headers(kwargs), **kwargs)
 
   def put(self, path, **kwargs):
-    if self.verbose: print "PUT %s" %  self.url(path)
+    if self.verbose: print ("PUT %s" %  self.url(path))
     return requests.put(self.url(path), headers = self._merge_headers(kwargs), **kwargs)
 
   def get(self, path, **kwargs):
-    if self.verbose: print "GET %s" %  self.url(path)
+    if self.verbose: print ("GET %s" %  self.url(path))
     return requests.get(self.url(path), headers = self._merge_headers(kwargs), **kwargs)
 
   def delete(self, path, **kwargs):
-    if self.verbose: print "DELETE %s" %  self.url(path)
+    if self.verbose: print ("DELETE %s" %  self.url(path))
     return requests.delete(self.url(path), headers = self._merge_headers(kwargs), **kwargs)
 
   def _merge_headers(self, kwargs):
